@@ -97,9 +97,6 @@ def main() :
     if  args.user :
         user = args.user
 
-    if not path.isdir(args.object_type) :
-        mkdir(args.object_type)
-
     if args.solution:
         solution_from_repo(args.solution, args.version)
 
